@@ -1,8 +1,8 @@
 package Apache::AxKit::Plugin::BasicAuth;
+# $Id: BasicAuth.pm,v 1.1 2003/09/09 16:35:26 nachbaur Exp $
 
 use strict;
 use Apache;
-use AxKit;
 use Apache::Constants qw(:common M_GET);
 use Apache::AuthCookie;
 use Apache::Session::Flex;
@@ -13,15 +13,13 @@ use base qw(Apache::AuthCookie);
 
 use constant IN_PROGRESS => 1;
 
-$VERSION = 0.23;
+$VERSION = 0.16;
 
 sub authen_cred {
     my $self = shift;
     my $r = shift;
     my @creds = @_;
-    AxKit::Debug(10, "[BAuth] Login name given as " . 
-		 (defined($Apache::AxKit::Plugin::BasicSession::session{"credential_0"}) 
-		  ? $Apache::AxKit::Plugin::BasicSession::session{"credential_0"} : "undef"));
+
     # Don't call this unless you've authenticated the user.
     return $Apache::AxKit::Plugin::BasicSession::session{"_session_id"}
         if (defined $Apache::AxKit::Plugin::BasicSession::session{"credential_0"});
@@ -32,11 +30,13 @@ sub authen_ses_key ($$$) {
     my $r = shift;
     my $sess_id = shift;
 
-    AxKit::Debug(9, "[BAuth] SessionID given to authen_ses_key ". (defined($sess_id) ? $sess_id : "undef"));
     # Session handling code
     return $Apache::AxKit::Plugin::BasicSession::session{credential_0}
         if ($Apache::AxKit::Plugin::BasicSession::session{_session_id} eq $sess_id);
 
+#    untie %Apache::AxKit::Plugin::BasicSession::session
+#      if (ref tied %Apache::AxKit::Plugin::BasicSession::session);
+
     my $prefix = $r->auth_name;
 
     my %flex_options = (
@@ -46,12 +46,6 @@ sub authen_ses_key ($$$) {
         Serialize => $r->dir_config( $prefix . 'Serialize' ) || 'Storable'
     );
 
-    # When using Postgres, a different default is needed.  
-    if ($flex_options{'Store'} eq 'Postgres') {
-        $flex_options{'Commit'} = 1;
-	$flex_options{'Serialize'} = $r->dir_config( $prefix . 'Serialize' ) || 'Base64'
-    }
-
     # Load session-type specific parameters
     foreach my $arg ( split( /\s*,\s*/, 
 			     $r->dir_config( $prefix . 'Args' ) ) ) {
@@ -63,8 +57,6 @@ sub authen_ses_key ($$$) {
 	     'Apache::Session::Flex',
 	     $sess_id, \%flex_options; };
 
-    AxKit::Debug(9, "[BAuth] Retrieved session has id $Apache::AxKit::Plugin::BasicSession::session{_session_id}.");
-
     # invoke the custom_errors handler so we don't get fried...
     return (0, 0)
       unless defined
