@@ -1,4 +1,5 @@
 package AxKit::XSP::BasicAuth;
+# $Id: BasicAuth.pm,v 1.1 2003/09/09 16:35:26 nachbaur Exp $
 
 use Apache;
 use Apache::AxKit::Language::XSP::TaglibHelper;
@@ -20,7 +21,7 @@ sub parse_start {
       if m{credential_(\d+)};
   }
   $r->headers_in->unset('Content-Length');
-  return $r->prev->uri if ($r->prev);}
+  return $r->prev->uri;}
   } elsif($tag eq 'logout') {
     $e->start_expr($tag);
     return q{$r->auth_type->logout($r, \%Apache::AxKit::Plugin::BasicSession::session)}
@@ -49,7 +50,7 @@ sub parse_end {
 }
 
 $NS = 'http://www.nichework.com/2003/XSP/BasicAuth';
-$VERSION = "0.22";
+$VERSION = "0.01";
 @EXPORT_TAGS = qw( login() logout() get-username() is-logged-in() );
 
 1;
@@ -77,7 +78,7 @@ And add this taglib to AxKit (via httpd.conf or .htaccess):
 
     <Location />
       AuthType Apache::AxKit::Plugin::BasicAuth
-      AuthName BasicSession
+      AuthName Weblog
     </Location>
     <Location /style>
       require valid-user
@@ -85,14 +86,14 @@ And add this taglib to AxKit (via httpd.conf or .htaccess):
 
     # Session Management
     AxAddPlugin Apache::AxKit::Plugin::BasicSession
-    PerlSetVar BasicSessionDataStore DB_File
-    PerlSetVar BasicSessionArgs      "FileName => /tmp/session"
+    PerlSetVar WeblogDataStore DB_File
+    PerlSetVar WeblogArgs      "FileName => /tmp/session"
 
     AxAddPlugin Apache::AxKit::Plugin::BasicSession
     AxAddPlugin Apache::AxKit::Plugin::AddXSLParams::BasicSession
 
     # Authentication
-    PerlSetVar BasicSessionLoginScript /login
+    PerlSetVar WeblogLoginScript /login
 
 =head1 DESCRIPTION
 
@@ -104,7 +105,7 @@ for AuthName.
 
 =head1 Tag Reference
 
-=head2 C<E<lt>auth:loginE<gt>>
+=head2 C<<auth:login>>
 
 Attempt to log the user in.
 
@@ -123,16 +124,16 @@ session information as well.  This allows you to store the plaintext
 user password in credential_1 if you need access to it (among other
 things).
 
-=head2 C<E<lt>auth:logoutE<gt>>
+=head2 C<<auth:logout>>
 
 Log the user out.  This is done by removing any keys that match the
 credential_\d+ regular expression from the session information.
 
-=head2 C<E<lt>auth:get-usernameE<gt>>
+=head2 C<<auth:get-username>>
 
 Returns the username that was used to log in.
 
-=head2 C<E<lt>auth:is-logged-inE<gt>>
+=head2 C<<auth:is-logged-in>>
 
 Returns true if the page if the session contains a logged in user.
 
